@@ -16,7 +16,8 @@ from ..common.lsp_types import InitializeError, Model
 from ..common.parts.document_symbols import symbol_information_label
 from ..common.protocol import LanguageServerProtocol
 from .configuration import RobotConfig
-from .parts.code_action import RobotCodeActionProtocolPart
+from .parts.code_action_documentation import RobotCodeActionDocumentationProtocolPart
+from .parts.code_action_fixes import RobotCodeActionFixesProtocolPart
 from .parts.codelens import RobotCodeLensProtocolPart
 from .parts.completion import RobotCompletionProtocolPart
 from .parts.debugging_utils import RobotDebuggingUtilsProtocolPart
@@ -96,7 +97,8 @@ class RobotLanguageServerProtocol(LanguageServerProtocol):
     robot_rename = ProtocolPartDescriptor(RobotRenameProtocolPart)
     robot_inline_value = ProtocolPartDescriptor(RobotInlineValueProtocolPart)
     robot_inlay_hint = ProtocolPartDescriptor(RobotInlayHintProtocolPart)
-    robot_code_action = ProtocolPartDescriptor(RobotCodeActionProtocolPart)
+    robot_code_action_documentation = ProtocolPartDescriptor(RobotCodeActionDocumentationProtocolPart)
+    robot_code_action_fixes = ProtocolPartDescriptor(RobotCodeActionFixesProtocolPart)
     robot_workspace = ProtocolPartDescriptor(RobotWorkspaceProtocolPart)
 
     robot_discovering = ProtocolPartDescriptor(DiscoveringProtocolPart)
